%define anolis_release 1
Name:           python-rpm-macros
Summary:        The common Python RPM macros

URL:            https://src.fedoraproject.org/rpms/python-rpm-macros/

# Macros:
Source101:      macros.python
Source102:      macros.python-srpm
Source104:      macros.python3
Source105:      macros.pybytecompile

# Lua files
Source201:      python.lua

# Python code
%global compileall2_version 0.7.1
Source301:      https://github.com/fedora-python/compileall2/raw/v%{compileall2_version}/compileall2.py
Source302:      import_all_modules.py
%global pathfix_version 1.0.0
Source303:      https://github.com/fedora-python/pathfix/raw/v%{pathfix_version}/pathfix.py
Source304:      clamp_source_mtime.py

# BRP scripts
Source401:      brp-python-bytecompile
# This one is from https://github.com/rpm-software-management/python-rpm-packaging/blob/main/scripts/brp-python-hardlink
# But we don't use a link in case it changes in upstream, there are no "versions" there yet
# This was removed from RPM 4.17+ so we maintain it here instead
Source402:      brp-python-hardlink
Source403:      brp-fix-pyc-reproducibility

# macros and lua: MIT
# import_all_modules.py: MIT
# compileall2.py, clamp_source_mtime.py: PSF-2.0
# pathfix.py: PSF-2.0
# brp scripts: GPL-2.0-or-later
License:        MIT AND PSF-2.0 AND GPL-2.0-or-later

# The package version MUST be always the same as %%{__default_python3_version}.
# To have only one source of truth, we load the macro and use it.
# The macro is defined in python-srpm-macros.
%{lua:
if posix.stat(rpm.expand('%{SOURCE102}')) then
  rpm.load(rpm.expand('%{SOURCE102}'))
elseif posix.stat('macros.python-srpm') then
  -- something is parsing the spec without _sourcedir macro properly set
  rpm.load('macros.python-srpm')
end
}
Version:        %{__default_python3_version}
Release:        %{anolis_release}%{?dist}
Epoch:          1

BuildArch:      noarch

# For %%__default_python3_pkgversion used in %%python_provide
# For python.lua
# For compileall2.py
Requires:       python-srpm-macros = %{EVR}

# The packages are called python(3)-(s)rpm-macros
# We never want python3-rpm-macros to provide python-rpm-macros
# We opt out from all Python name-based automatic provides and obsoletes
%undefine __pythonname_provides
%undefine __pythonname_obsoletes

%description
This package contains the unversioned Python RPM macros, that most
implementations should rely on.

You should not need to install this package manually as the various
python?-devel packages require it. So install a python-devel package instead.


%package -n python-srpm-macros
Summary:        RPM macros for building Python source packages
Requires:       system-rpm-config

# We bundle our own software here :/
Provides:       bundled(python3dist(compileall2)) = %{compileall2_version}

%description -n python-srpm-macros
RPM macros for building Python source packages.


%package -n python3-rpm-macros
Summary:        RPM macros for building Python 3 packages

# For %%__python3 and %%python3
Requires:       python-srpm-macros = %{EVR}

# For %%py_setup and import_all_modules.py
Requires:       python-rpm-macros = %{EVR}

%description -n python3-rpm-macros
RPM macros for building Python 3 packages.


%prep
%autosetup -c -T
cp -a %{sources} .

# We want to have shebang in the script upstream but not here so
# the package with macros does not depend on Python.
sed -i '1s=^#!/usr/bin/env python3==' pathfix.py


%install
mkdir -p %{buildroot}%{rpmmacrodir}
install -m 644 macros.* %{buildroot}%{rpmmacrodir}/

mkdir -p %{buildroot}%{_rpmluadir}/anolis/srpm
install -p -m 644 -t %{buildroot}%{_rpmluadir}/anolis/srpm python.lua

mkdir -p %{buildroot}%{_rpmconfigdir}/anolis
install -m 644 compileall2.py %{buildroot}%{_rpmconfigdir}/anolis/
install -m 644 clamp_source_mtime.py %{buildroot}%{_rpmconfigdir}/anolis/
install -m 644 import_all_modules.py %{buildroot}%{_rpmconfigdir}/anolis/
install -m 644 pathfix.py %{buildroot}%{_rpmconfigdir}/anolis/
install -m 755 brp-* %{buildroot}%{_rpmconfigdir}/anolis/


# We define our own BRPs here to use the ones from the %%{buildroot},
# that way, this package can be built when it includes them for the first time.
# It also ensures that:
#  - our BRPs can execute
#  - if our BRPs affect this package, we don't need to build it twice
%define add_buildroot() %{lua:print((macros[macros[1]]:gsub(macros._rpmconfigdir, macros.buildroot .. macros._rpmconfigdir)))}
%global __brp_python_bytecompile %{add_buildroot __brp_python_bytecompile}
%global __brp_python_hardlink %{add_buildroot __brp_python_hardlink}
%global __brp_fix_pyc_reproducibility %{add_buildroot __brp_fix_pyc_reproducibility}


%check
# no macros in comments
grep -E '^#[^%%]*%%[^%%]' %{buildroot}%{rpmmacrodir}/macros.* && exit 1 || true


%files
%{rpmmacrodir}/macros.python
%{rpmmacrodir}/macros.pybytecompile
%{_rpmconfigdir}/anolis/import_all_modules.py
%{_rpmconfigdir}/anolis/pathfix.py

%files -n python-srpm-macros
%{rpmmacrodir}/macros.python-srpm
%{_rpmconfigdir}/anolis/compileall2.py
%{_rpmconfigdir}/anolis/clamp_source_mtime.py
%{_rpmconfigdir}/anolis/brp-python-bytecompile
%{_rpmconfigdir}/anolis/brp-python-hardlink
%{_rpmconfigdir}/anolis/brp-fix-pyc-reproducibility
%{_rpmluadir}/anolis/srpm/python.lua

%files -n python3-rpm-macros
%{rpmmacrodir}/macros.python3


%changelog
* Wed Feb 26 2025 Zhao Hang <wb-zh951434@alibaba-inc.com> - 1:3.11-1
- Update to 1:3.11-1 from 3.11-23.2
- Declare the license as an SPDX expression

* Tue Mar  5 2024 Liwei Ge <liwei.glw@alibaba-inc.com> - 3.11-23.2
- Built with python3.11

* Mon Feb 28 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 3.10-23.1
- init python3.10 from upstream
